@@ -6,6 +6,8 @@
 
 #pragma once
 
+#include <glib.h>
+
 /**
  * JCAT_MAJOR_VERSION:
  *
@@ -30,7 +32,7 @@
  * The compile-time micro version
  */
 #ifndef JCAT_MICRO_VERSION
-#define JCAT_MICRO_VERSION (10)
+#define JCAT_MICRO_VERSION (13)
 #endif
 
 /**
@@ -47,3 +49,5 @@
 	 (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION > (minor)) ||                        \
 	 (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION == (minor) &&                        \
 	  JCAT_MICRO_VERSION >= (micro)))
+
+const gchar	*jcat_version_string	(void);
